@@ -6,7 +6,7 @@ All rights reserved.
 This software may be modified and distributed under the terms
 of the BSD license. See the LICENSE file for details.
 """
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from sys import version_info
 
