@@ -7,7 +7,7 @@ This software may be modified and distributed under the terms
 of the BSD license. See the LICENSE file for details.
 """
 
-from __future__ import print_function, unicode_literals
+from __future__ import print_function, unicode_literals, absolute_import
 
 import json
 import logging
@@ -228,13 +228,13 @@ class DockerfileParser(object):
                 'instruction': instruction,
                 'startline': lineno,
                 'endline': lineno,
-                'content': line,
+                'content': line,  # pylint: disable=undefined-loop-variable
                 'value': value
             }
 
         def _clean_comment_line(line):
             line = re.sub(r'^\s*#\s*', '', line)
-            line = re.sub('\n', '', line)
+            line = re.sub(r'\n', '', line)
             return line
 
 
@@ -243,7 +243,7 @@ class DockerfileParser(object):
         insnre = re.compile(r'^\s*(\S+)\s+(.*)$')  # matched group is insn
         contre = re.compile(r'^.*\\\s*$')          # line continues?
         commentre = re.compile(r'^\s*#')           # line is a comment?
-        
+
         in_continuation = False
         current_instruction = None
 
@@ -265,16 +265,19 @@ class DockerfileParser(object):
                     if not m:
                         continue
                     current_instruction = _create_instruction_dict(
-                        instruction=m.groups()[0].upper(), 
+                        instruction=m.groups()[0].upper(),
                         value=_rstrip_backslash(m.groups()[1])
                     )
                 else:
                     current_instruction['content'] += line
                     current_instruction['endline'] = lineno
+
+                    # pylint: disable=unsupported-assignment-operation
                     if current_instruction['value']:
                         current_instruction['value'] += _rstrip_backslash(line)
                     else:
                         current_instruction['value'] = _rstrip_backslash(line.lstrip())
+                    # pylint: enable=unsupported-assignment-operation
 
                 in_continuation = contre.match(line)
                 if not in_continuation and current_instruction is not None:
@@ -420,7 +423,7 @@ class DockerfileParser(object):
         :return: Labels instance or Envs instance
         """
         if name != 'LABEL' and name != 'ENV':
-            raise ValueError("Unsupported instruction '%s'", name)
+            raise ValueError("Unsupported instruction '%s'" % name)
         instructions = {}
         envs = {}
 
@@ -628,7 +631,7 @@ class DockerfileParser(object):
         all_stages = kwargs.pop('all_stages', False)
         at_start = kwargs.pop('at_start', False)
         skip_scratch = kwargs.pop('skip_scratch', False)
-        assert not kwargs, "Unknown keyword argument(s): {0}".format(kwargs.keys())
+        assert not kwargs, "Unknown keyword argument(s): {0}".format(list(kwargs))
 
         froms = [
             instr for instr in self.structure
@@ -667,12 +670,12 @@ class DockerfileParser(object):
         replace = kwargs.pop('replace', False)
         after = kwargs.pop('after', False)
         assert not (after and replace)
-        assert not kwargs, "Unknown keyword argument(s): {0}".format(kwargs.keys())
+        assert not kwargs, "Unknown keyword argument(s): {0}".format(list(kwargs))
 
         # find the line number for the insertion
         df_lines = self.lines
         if isinstance(anchor, int):  # line number, just validate
-            assert anchor in range(len(df_lines))
+            assert 0 <= anchor < len(df_lines)
             if replace:
                 del df_lines[anchor]
         elif isinstance(anchor, dict):  # structure
