@@ -7,7 +7,7 @@ This software may be modified and distributed under the terms
 of the BSD license. See the LICENSE file for details.
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import pytest
 import six
@@ -15,7 +15,10 @@ import six
 from dockerfile_parse import DockerfileParser
 
 
-@pytest.fixture(params=[(use_fileobj, cache_content) for use_fileobj in [True, False] for cache_content in [True, False]])
+@pytest.fixture(
+    params=[(use_fileobj, cache_content)
+            for use_fileobj in [True, False]
+            for cache_content in [True, False]])
 def dfparser(tmpdir, request):
     """
 
@@ -26,8 +29,8 @@ def dfparser(tmpdir, request):
 
     use_fileobj, cache_content = request.param
     if use_fileobj:
-        file = six.BytesIO()
-        return DockerfileParser(fileobj=file, cache_content=cache_content)
+        fileobj = six.BytesIO()
+        return DockerfileParser(fileobj=fileobj, cache_content=cache_content)
     else:
         tmpdir_path = str(tmpdir.realpath())
         return DockerfileParser(path=tmpdir_path, cache_content=cache_content)
