@@ -7,7 +7,7 @@ This software may be modified and distributed under the terms
 of the BSD license. See the LICENSE file for details.
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import inspect
 import json
@@ -25,8 +25,8 @@ from tests.fixtures import dfparser, instruction
 
 NON_ASCII = "žluťoučký"
 # flake8 does not understand fixtures:
-dfparser = dfparser
-instruction = instruction
+dfparser = dfparser  # pylint: disable=self-assigning-variable
+instruction = instruction  # pylint: disable=self-assigning-variable
 
 
 class TestDockerfileParser(object):
@@ -96,14 +96,14 @@ class TestDockerfileParser(object):
                           "# comment \\\n",             # extra ws
                           "# with \\ \n",               # extra ws with a space
                           "# backslashes \\\\ \n",      # two backslashes
-                          "#no space after hash\n",       
-                          "# comment # with hash inside\n",      
+                          "#no space after hash\n",
+                          "# comment # with hash inside\n",
                           "RUN command1\n",
                           "RUN command2 && \\\n",
                           "    command3\n",
                           "RUN command4 && \\\n",
                           "# interrupt RUN\n",          # comment interrupting multi-line RUN
-                          "    command5\n",                        
+                          "    command5\n",
                         ]
 
         assert dfparser.structure == [
@@ -298,6 +298,7 @@ class TestDockerfileParser(object):
         assert not df1.envs
 
     @pytest.mark.parametrize(('instr_value', 'expected'), [
+        # pylint: disable=anomalous-backslash-in-string
         ('"name1"=\'value 1\' "name2"=myself name3=""',
          {'name1': 'value 1',
           'name2': 'myself',
@@ -630,7 +631,8 @@ class TestDockerfileParser(object):
         # Simple case, '=' but no quotes
         ('Release=1', 'Release', '6', 'Release=6'),
         # '=' and quotes, with space in the value
-        ('"Name"=\'alpha alpha\' Version=1', 'Name', 'beta delta', '"Name"=\'beta delta\' Version=1'),
+        ('"Name"=\'alpha alpha\' Version=1',
+         'Name', 'beta delta', '"Name"=\'beta delta\' Version=1'),
         ('Name=foo', 'Name', 'new value', "Name='new value'"),
         # ' ' and quotes
         ('"Name" alpha alpha', 'Name', 'beta delta', "\"Name\" 'beta delta'"),
@@ -733,7 +735,7 @@ class TestDockerfileParser(object):
                           "LABEL TEST={0}\n".format(label)]
         try:
             dfparser.labels['TEST']
-        except:
+        except KeyError:
             pass
 
     def test_env_multistage(self, dfparser):
@@ -896,16 +898,17 @@ class TestDockerfileParser(object):
             "version": "1.0.❤"
         }
 
-        assert c[6].get_values(context_type=instruction) == {"multi.label❤1": "value❤1",
-                                                             "multi.label❤2": "value❤2",
-                                                             "other": "othervalue3",
-                                                             "2multi.label1": "othervalue1",
-                                                             "2multi.label2": "othervalue2",
-                                                             "com.example.vendor": "ACME Incorporated",
-                                                             "com.example.label-with-value": "foo",
-                                                             "version": "1.0.❤",
-                                                             "description": "This text illustrates that label-values can span multiple lines."
-                                                             }
+        assert c[6].get_values(context_type=instruction) == {
+            "multi.label❤1": "value❤1",
+            "multi.label❤2": "value❤2",
+            "other": "othervalue3",
+            "2multi.label1": "othervalue1",
+            "2multi.label2": "othervalue2",
+            "com.example.vendor": "ACME Incorporated",
+            "com.example.label-with-value": "foo",
+            "version": "1.0.❤",
+            "description": "This text illustrates that label-values can span multiple lines."
+        }
 
     def test_context_structure_mixed(self, dfparser, instruction):
         dfparser.content = dedent("""\
@@ -987,7 +990,7 @@ class TestDockerfileParser(object):
         ]
         with pytest.raises(ValueError) as exc_info:
             if action == 'get':
-                dfparser.labels
+                dfparser.labels  # pylint: disable=pointless-statement
             elif action == 'set':
                 dfparser.labels = {}
         if six.PY2:
@@ -1147,7 +1150,7 @@ class TestDockerfileParser(object):
             LABEL a=b c=d e=❤""")  # no newline
         dfparser.add_lines_at(2, "# something new ❤", after=True)
         assert "d#" not in dfparser.content
-        assert 4 == len(dfparser.lines)
+        assert len(dfparser.lines) == 4
         assert "something new ❤" in dfparser.lines[3]
 
     def test_add_lines_after_continuation(self, dfparser):
